﻿Public Class ViewerForm

    Const c_defPromptOnExit As Boolean = False
    Private m_strUserName As String
    Private m_blnPromptOnExit As Boolean
    Private m_objPictureBackColor As Color

    Private Enum PrintDestination
        Printer = 0
        PrintPreview = 1
    End Enum


    Private Sub btnEnlarge_Click(sender As Object, e As EventArgs) Handles btnEnlarge.Click
        Me.Width = Me.Width + 20
        Me.Height = Me.Height + 20

    End Sub

    Private Sub btnShrink_Click(sender As Object, e As EventArgs) Handles btnShrink.Click
        Me.Width = Me.Width - 20
        Me.Height = Me.Height - 20

    End Sub

    Private Sub picShowPicture_MouseLeave(sender As Object, e As EventArgs) Handles picShowPicture.MouseLeave
        lblX.Text = ""
        lblY.Text = ""

    End Sub


    Private Sub picShowPicture_MouseMove(sender As Object, e As MouseEventArgs) Handles picShowPicture.MouseMove
        lblX.Text = "X: " & e.X
        lblY.Text = "Y: " & e.Y
    End Sub

    Private Sub ViewerForm_FormClosing(sender As Object, e As FormClosingEventArgs) Handles Me.FormClosing
        If m_blnPromptOnExit Then
            If MessageBox.Show("Close the Picture Viewer program?", _
                               "Picture Viewer", MessageBoxButtons.YesNo,
                               MessageBoxIcon.Question) = _
                           Windows.Forms.DialogResult.No Then
                e.Cancel = True
            End If
        End If
    End Sub


    Private Sub ViewerForm_Load(sender As Object, e As EventArgs) Handles Me.Load
        lblX.Text = ""
        lblY.Text = ""

        LoadDefaults()

    End Sub

    Public Sub LoadDefaults()
        Const c_strKeyName As String = _
    "HKEY_CURRENT_USER\Software\CleverSoftware\PictureViewer\"

        m_blnPromptOnExit = CBool(My.Computer.Registry.GetValue _
            (c_strKeyName, "PromptOnExit", "0"))

        If CStr(My.Computer.Registry.GetValue _
            (c_strKeyName, "BackColor", "Gray")) = "Gray" Then
            m_objPictureBackColor = System.Drawing.SystemColors.Control
        Else
            m_objPictureBackColor = System.Drawing.Color.White
        End If

        picShowPicture.BackColor = m_objPictureBackColor

        mnuConfirmOnExit.Checked = m_blnPromptOnExit
    End Sub


    Private Sub mnuOpenPicture_Click(sender As Object, e As EventArgs) Handles mnuOpenPicture.Click
        OpenPicture()
    End Sub

    Private Sub mnuConfirmOnExit_Click(sender As Object, e As EventArgs) Handles mnuConfirmOnExit.Click
        mnuConfirmOnExit.Checked = Not (mnuConfirmOnExit.Checked)
        m_blnPromptOnExit = mnuConfirmOnExit.Checked

    End Sub

    Private Sub mnuQuit_Click(sender As Object, e As EventArgs) Handles mnuQuit.Click
        Me.Close()
    End Sub

    Private Sub mnuDrawBorder_Click(sender As Object, e As EventArgs) Handles mnuDrawBorder.Click
        DrawBorder(picShowPicture)
    End Sub

    Private Sub mnuOptions_Click(sender As Object, e As EventArgs) Handles mnuOptions.Click
        OptionsForm.ShowDialog()
    End Sub

    Private Sub tbbOpenPicture_Click(sender As Object, e As EventArgs) Handles tbbOpenPicture.Click
        OpenPicture()
    End Sub

    Private Sub tbbDrawBorder_Click(sender As Object, e As EventArgs) Handles tbbDrawBorder.Click
        DrawBorder(picShowPicture)
    End Sub

    Private Sub tbbOptions_Click(sender As Object, e As EventArgs) Handles tbbOptions.Click
        OptionsForm.ShowDialog()
    End Sub

    Private Sub tbbGetFileAttributes_Click(sender As Object, e As EventArgs) Handles tbbGetFileAttributes.Click
        showfileattributes()
    End Sub

    Private Sub tbbShowLog_Click(sender As Object, e As EventArgs) Handles tbbShowLog.Click
        LogViewerForm.ShowDialog()

    End Sub

    Private Sub ViewLogToolStripMenuItem_Click(sender As Object, e As EventArgs) Handles ViewLogToolStripMenuItem.Click
        LogViewerForm.ShowDialog()
    End Sub

    Private Sub GetFileAttributesToolStripMenuItem_Click(sender As Object, e As EventArgs) Handles GetFileAttributesToolStripMenuItem.Click
        showfileattributes()
    End Sub

    Private Sub ShowFileAttributes()
        Dim strProperties As String
        Dim lngAttributes As Long

        If ofdSelectPicture.FileName = "" Then Exit Sub

        ' Get the dates.
        strProperties = "Created: " & _
              System.IO.File.GetCreationTime(ofdSelectPicture.FileName)

        strProperties = strProperties & vbCrLf
        strProperties = strProperties & "Accessed: " & _
              System.IO.File.GetLastAccessTime(ofdSelectPicture.FileName)
        strProperties = strProperties & vbCrLf
        strProperties = strProperties & "Modified: " & _
              System.IO.File.GetLastWriteTime(ofdSelectPicture.FileName)

        ' Get the file attributes.
        lngAttributes = System.IO.File.GetAttributes(ofdSelectPicture.FileName)

        ' Use a binary AND to extract the specific attributes.
        strProperties = strProperties & vbCrLf
        strProperties = strProperties & "Normal: " & _
              CBool(lngAttributes And IO.FileAttributes.Normal)

        strProperties = strProperties & vbCrLf
        strProperties = strProperties & "Hidden: " & _
              CBool(lngAttributes And IO.FileAttributes.Hidden)

        strProperties = strProperties & vbCrLf
        strProperties = strProperties & "ReadOnly: " & _
              CBool(lngAttributes And IO.FileAttributes.ReadOnly)

        strProperties = strProperties & vbCrLf
        strProperties = strProperties & "System: " & _
              CBool(lngAttributes And IO.FileAttributes.System)

        strProperties = strProperties & vbCrLf
        strProperties = strProperties & "Temporary File: " & _
              CBool(lngAttributes And IO.FileAttributes.Temporary)

        strProperties = strProperties & vbCrLf
        strProperties = strProperties & "Archive: " & _
              CBool(lngAttributes And IO.FileAttributes.Archive)

        MessageBox.Show(strProperties, "Picture Viewer")
    End Sub

    Private Sub PrintImage(ByVal Destination As PrintDestination)

        If ofdSelectPicture.FileName = "" Then
            MessageBox.Show("There is no image to print.", "Picture Viewer", _
                            MessageBoxButtons.OK, MessageBoxIcon.Exclamation)
            Exit Sub

        End If

        ChangePageSettings()

        If Destination = PrintDestination.PrintPreview Then
            ' Specify document for print preview dialog box and show.
            PrintPreviewDialog1.Document = PrintDocument1
            PrintPreviewDialog1.ShowDialog()
        Else
            PrintDocument1.Print()
        End If
    End Sub


    Private Sub tbbPrint_Click(sender As Object, e As EventArgs) Handles tbbPrint.Click
        PrintImage(PrintDestination.Printer)
    End Sub

    Private Sub tbbPrintPreview_Click(sender As Object, e As EventArgs) Handles tbbPrintPreview.Click
        PrintImage(PrintDestination.PrintPreview)
    End Sub

    Private Sub PrintDocument1_PrintPage(sender As Object, e As Printing.PrintPageEventArgs) Handles PrintDocument1.PrintPage
        ' Create a rectangle the sizeof the printable area of the page.
        Dim recPrintable As New Rectangle( _
                e.MarginBounds.Left, e.MarginBounds.Top, _
                e.MarginBounds.Width, e.MarginBounds.Height)

        ' Create a rectangle used for the actual drawing dimensions of the image.
        ' Default it to the printable area.
        Dim recDraw As Rectangle = recPrintable

        ' Load the image in a bitmap object we can use.
        Dim bmSource As New Bitmap(ofdSelectPicture.FileName)

        ResizeToPrintableArea(bmSource, recDraw, recPrintable)

        ' Draw the bitmap on the Graphics object of the PrintDocument control.
        e.Graphics.DrawImage(bmSource, recDraw)

        ' This is the last page to be printed.
        e.HasMorePages = False

        ' Free up resources used.
        bmSource.Dispose()

    End Sub

    Private Sub ChangePageSettings()
        ' Let the user change printer settings
        Dim PrintPageSettings As New System.Drawing.Printing.PageSettings

        ' set default margins
        ' Margings are in 100ths of an inch.
        PrintPageSettings.Margins.Left = 200
        PrintPageSettings.Margins.Right = 200
        PrintPageSettings.Margins.Top = 200
        PrintPageSettings.Margins.Bottom = 200

        PageSetupDialog1.PageSettings = PrintPageSettings

        PageSetupDialog1.ShowDialog()

        ' Use the selected settings
        PrintDocument1.DefaultPageSettings = PrintPageSettings

    End Sub

    Private Sub ResizeToPrintableArea(ByRef img As Bitmap, _
                                      ByRef recDraw As Rectangle, ByRef recPrintable As Rectangle)

        ' Which is bigger in the source image, the height or width?
        If img.Width > img.Height Then
            ' Which is bigger on destination rectangle, height or width?
            If recPrintable.Width > recPrintable.Height Then
                ' Height is the constraint.
                recDraw.Width = CInt(recDraw.Height * (img.Width / img.Height))
            Else
                ' Width is the constraint.
                recDraw.Height = CInt(recDraw.Width * (img.Height / img.Width))
            End If
        Else
            ' The height is greater than or equal to the width.
            ' Which is bigger on destination rectangle, height or width?
            If recPrintable.Height > recPrintable.Width Then
                ' Width is the constraint.
                recDraw.Height = CInt(recDraw.Width * (img.Height / img.Width))
            Else
                ' Height is the constraint.
                recDraw.Width = CInt(recDraw.Height * (img.Width / img.Height))
            End If
        End If
    End Sub

    Private Sub mnuPrint_Click(sender As Object, e As EventArgs) Handles mnuPrint.Click
        PrintImage(PrintDestination.Printer)
    End Sub

    Private Sub mnuPrintPreview_Click(sender As Object, e As EventArgs) Handles mnuPrintPreview.Click
        PrintImage(PrintDestination.PrintPreview)
    End Sub
End Class
